OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "O seu cliente não está autorizado a conectar-se. Por favor, informe o administrador do seu cliente.",
    "OAuth 2.0" : "OAuth 2.0",
    "OAuth 2.0 clients" : "Clientes OAuth 2.0",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "OAuth2.0 permite que dispositivos externos peçam acesso a {instanceName}.",
    "Name" : "Nome",
    "Redirection URI" : "URI de redireccionamento",
    "Client Identifier" : "Identificador de Cliente",
    "Secret" : "Segredo",
    "Add client" : "Adicionar cliente",
    "Add" : "Adicionar",
    "Show client secret" : "Mostrar segredo do cliente",
    "Delete" : "Apagar"
},
"nplurals=2; plural=(n != 1);");
